#
# spec file for package ghc-warp
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name warp

%bcond_with tests

Name:           ghc-warp
Version:        3.2.6
Release:        1.2
Summary:        A fast, light-weight web server for WAI applications
License:        MIT
Group:          System/Libraries

Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE cabal-deps.patch mimi.vx@gmail.com
Patch0:         cabal-deps.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-auto-update-devel
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-http-date-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-http2-devel
BuildRequires:  ghc-iproute-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-simple-sendfile-devel
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-streaming-commons-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-unix-compat-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-vault-devel
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-word8-devel
%if %{with tests}
BuildRequires:  ghc-HTTP-devel
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-lifted-base-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-silently-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
%endif
# End cabal-rpm deps

%description
HTTP/1.0, HTTP/1.1 and HTTP/2 are supported. For HTTP/2, Warp supports direct
and ALPN (in TLS) but not upgrade. API docs and the README are available at
<http://www.stackage.org/package/warp>.


%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       %{name} = %{version}-%{release}

%description devel
This package provides the Haskell %{pkg_name} library development files.


%prep
%setup -q -n %{pkg_name}-%{version}
%patch0 -p1

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%if %{with tests}
%cabal test
%endif

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc README.md

%changelog
* Sat Apr  9 2016 mimi.vx@gmail.com
- update to 3.2.6
  * Using token based APIs of http2 1.6.
  * Ignoring errors from setSocketOption
  * Added withApplication, testWithApplication, and openFreePort
  * Fixing reaper delay value of file info cache.
* Wed Feb 24 2016 mimi.vx@gmail.com
- update to 3.2.3
  * Using http2 v1.5.x which much improves the performance of HTTP/2
  * To get rid of the bottleneck of ByteString's (==), a new logic to compare header
    names is introduced.
* Wed Jan 20 2016 mimi.vx@gmail.com
- update to 3.2.2
  * Throwing errno for pread
  * Add back warpVersion
  * Major version up due to breaking changes. This is because the HTTP/2 code was
    started over with Warp 3.1.3 due to performance issue
  * runHTTP2, runHTTP2Env, runHTTP2Settings and runHTTP2SettingsSocket were removed
    from the Network.Wai.Handler.Warp module.
  * The performance of HTTP/2 was drastically improved. Now the performance of HTTP/2
    is almost the same as that of HTTP/1.1.
  * The logic to handle files in HTTP/2 is now identical to that in HTTP/1.1.
  * Internal stuff was removed from the Network.Wai.Handler.Warp module
    according to the plan.
* Fri Dec 25 2015 mimi.vx@gmail.com
- update to 3.1.12
- refresh cabal-deps.patch
  * Setting lower bound for auto-update
  * Providing a new API: killManager.
  * Preventing space leaks due to Weak ThreadId
  * Setting upper bound for http2.
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 3.1.10
  * setFileInfoCacheDuration
  * setLogger
  * FileInfo/getFileInfo
  * Fix: warp-tls strips out the Host request header
  * Using the new priority queue based on PSQ provided by http2 lib.
  * A concatenated Cookie header is prepended to the headers to ensure that it
    flows pseudo headers.
  * Providing a new settings: setHTTP2Disabled
  * Using http-types v0.9.
  * Using newer http2 library to prevent change table size attacks.
  * API for HTTP/2 server push and trailers.
  * Preventing response splitting attacks.
  * Concatenating multiple Cookie: headers in HTTP/2.
* Sun Oct  4 2015 mimi.vx@gmail.com
- update to 3.1.3.1
* Sat Sep 12 2015 mimi.vx@gmail.com
- initial commit
  * add cabal-deps.patch to remove bytestring-builder from cabal file
